.. nodoctest

Ranking Scale for Ultimate Frisbee
==================================

.. This file has been autogenerated.

.. automodule:: slabbe.ranking_scale
   :members:
   :undoc-members:
   :show-inheritance:
   

